#include <QtGui/QApplication>
#include <Phonon>
#include "mainwindow.h"
#include "symfoniemediaplayer.cpp"
#include "symfonieplaylistitemfolder.h"
#include "symfoniedb.h"
#include "symfoniesong.h"
#include "symfoniemetareader.h"

int main(int argc, char *argv[])
{
    QApplication a(argc, argv);
    a.setApplicationName("Symfonie");
    a.setQuitOnLastWindowClosed(true);
    SymfonieDb::createInstance();
    SymfonieMediaPlayer *player =  new SymfonieMediaPlayer();


    MainWindow w(&a, player);
    w.show();

    SymfonieMetaReader reader;
    reader.start();
    return a.exec();
}
